@@ -25,20 +25,24 @@ class FootGroup(object):
     def __init__(self, dialog):
         self.group_id = None
         self.dialog = dialog
-        self.submit_button_id = None
         self.connect_button_id = None
+        self.reset_button_id = None
         self.validate_button_id = None
+        self.submit_button_id = None
         self._build()
 
     def _build(self):
-        with footer_group(self.dialog, cols=3) as group_id:
+        with footer_group(self.dialog, cols=4) as group_id:
             self.group_id = group_id
             self.connect_button_id = self.dialog.register()
             self.submit_button_id = self.dialog.register()
             self.validate_button_id = self.dialog.register()
+            self.reset_button_id = self.dialog.register()
 
             self.dialog.AddButton(self.connect_button_id,
                                   c4d.BFV_CENTER,  name="Connect")
+            self.dialog.AddButton(self.reset_button_id,
+                                  c4d.BFV_CENTER,  name="Reset UI")
             self.dialog.AddButton(self.validate_button_id,
                                   c4d.BFV_CENTER,  name="Validate")
             self.dialog.AddButton(self.submit_button_id,
