@@ -6,7 +6,7 @@ import re
 
 import c4d
 from cioc4d import asset_cache
-from ciocore.expander import Expander
+# from ciocore.expander import Expander
 from ciocore.gpath import Path
 from ciocore.gpath_list import GLOBBABLE_REGEX, PathList
 from ciocore.validator import ValidationError, Validator
@@ -46,14 +46,12 @@ class ValidateTaskCount(Validator):
 class ValidateDestinationDirectoryClash(Validator):
     def run(self, _):
         dialog = self._submitter
-        context = dialog.get_context()
-        expander = Expander(safe=True, **context)
-        dest = expander.evaluate(dialog.section(
-            "GeneralSection").destination_widget.get_value())
 
+        dest = dialog.section("GeneralSection").resolve_destination_path()
+
+        # Validate path containment without drive letters
         dest_path = Path(dest).posix_path(with_drive=False)
-        # print "dest_path:" dest_path
-
+ 
         for gpath in asset_cache.data(self._submitter):
             asset_path = gpath.posix_path(with_drive=False)
             if asset_path.startswith(dest_path):
@@ -75,10 +73,11 @@ class ValidateRenderToDestinationDirectory(Validator):
         # TODO, break this up into its component parts
 
         dialog = self._submitter
-        context = dialog.get_context()
-        expander = Expander(safe=True, **context)
-        dest = expander.evaluate(dialog.section(
-            "GeneralSection").destination_widget.get_value())
+        # context = dialog.get_context()
+        # expander = Expander(safe=True, **context)
+
+
+        dest = dialog.section("GeneralSection").resolve_destination_path()
 
         dest_path = Path(dest).posix_path(with_drive=False)
 
@@ -128,6 +127,12 @@ class ValidateRenderToDestinationDirectory(Validator):
             document,
             render_data):
 
+
+        common_help =   """If you continue, your submission will probably fail. 
+Images should be written somewhere below the Destination Directory. 
+You should change either the path in Render Settings, or the Conductor destination directory."""
+
+
         if override_flag in task_template:
             self.add_notice(
                 """Your task template overrides the Render Settings image path with the {} flag. 
@@ -135,33 +140,29 @@ This is fine, but please ensure it points to a writable directory.
 It should be somewhere inside the Destination Directory. Check the Preview pane.""".format(override_flag))
             return
 
-        if do_save:
-            try:
-                image_path = render_data[c4d_filename_id]
-                if image_path:
-                    if Path(image_path).relative:
-                        image_path = os.path.join(
-                            document.GetDocumentPath(), image_path)
+        image_path = render_data[c4d_filename_id]
 
-                    image_path = Path(image_path).posix_path(with_drive=False)
+        if not (image_path and do_save):
+            self.add_notice(
+                "This file does not specify an output {}. ".format(label))
+            return
 
-                    if not image_path.startswith(dest_path):
-                        self.add_warning(
-                            """The {} path you've set in Render Settings does not point to a writable location. 
-If you continue, your submission will probably fail. 
-Images should be written somewhere below the Destination Directory. 
-You should change either the path in Render Settings, or the Conductor destination directory.""".format(label))
-                        return
-            except ValueError:
+        try:
+            if Path(image_path).relative:
+                image_path = os.path.join(
+                    document.GetDocumentPath(), image_path)
+
+            image_path = Path(image_path).posix_path(with_drive=False)
+
+            if not image_path.startswith(dest_path):
                 self.add_warning(
-                    """The {} path set in Render Settings is not a valid path. 
-If you continue, your submission will probably fail. 
-Images should be written somewhere below the Destination Directory as specified in the general section of the Conductor dialog. 
-You should change either the path in Render Settings, or the Conductor destination directory.""".format(label))
-                return
-        self.add_warning(
-            "This file does not specify an output {}.".format(label))
-
+                    """The {} path you've set in Render Settings does not point to a writable location.
+{}""".format(label, common_help))
+            return
+        except ValueError:
+            self.add_warning(
+                """The {} path set in Render Settings is not a valid path.
+{}""".format(label, common_help))
 
 class ValidateMissingExtraAssets(Validator):
 
